pub struct CaptchaDatadomeResult {
pub outcome: DataDomeOutcome,
pub tab_id: String,
pub elapsed_ms: u64,
}Fields
outcome: DataDomeOutcometab_id: Stringelapsed_ms: u64Trait Implementations
Sourceimpl Clone for CaptchaDatadomeResult
impl Clone for CaptchaDatadomeResult
Sourceimpl Debug for CaptchaDatadomeResult
impl Debug for CaptchaDatadomeResult
Sourceimpl<'de> Deserialize<'de> for CaptchaDatadomeResult
impl<'de> Deserialize<'de> for CaptchaDatadomeResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CaptchaDatadomeResult
impl JsonSchema for CaptchaDatadomeResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CaptchaDatadomeResult
impl RefUnwindSafe for CaptchaDatadomeResult
impl Send for CaptchaDatadomeResult
impl Sync for CaptchaDatadomeResult
impl Unpin for CaptchaDatadomeResult
impl UnsafeUnpin for CaptchaDatadomeResult
impl UnwindSafe for CaptchaDatadomeResult