pub struct DownloadWaitArgs {
pub id: String,
pub timeout_ms: u64,
}Fields
id: Stringtimeout_ms: u64Trait Implementations
Sourceimpl Clone for DownloadWaitArgs
impl Clone for DownloadWaitArgs
Sourceimpl Debug for DownloadWaitArgs
impl Debug for DownloadWaitArgs
Sourceimpl<'de> Deserialize<'de> for DownloadWaitArgs
impl<'de> Deserialize<'de> for DownloadWaitArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DownloadWaitArgs
impl JsonSchema for DownloadWaitArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DownloadWaitArgs
impl RefUnwindSafe for DownloadWaitArgs
impl Send for DownloadWaitArgs
impl Sync for DownloadWaitArgs
impl Unpin for DownloadWaitArgs
impl UnsafeUnpin for DownloadWaitArgs
impl UnwindSafe for DownloadWaitArgs