pub struct EmulateArgs {
pub width: u32,
pub height: u32,
pub dpr: f64,
pub desktop: bool,
pub reset: bool,
}Fields
width: u32height: u32dpr: f64desktop: boolreset: boolTrait Implementations
Sourceimpl Clone for EmulateArgs
impl Clone for EmulateArgs
Sourceimpl Debug for EmulateArgs
impl Debug for EmulateArgs
Sourceimpl Default for EmulateArgs
impl Default for EmulateArgs
Sourceimpl<'de> Deserialize<'de> for EmulateArgs
impl<'de> Deserialize<'de> for EmulateArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmulateArgs
impl JsonSchema for EmulateArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmulateArgs
impl RefUnwindSafe for EmulateArgs
impl Send for EmulateArgs
impl Sync for EmulateArgs
impl Unpin for EmulateArgs
impl UnsafeUnpin for EmulateArgs
impl UnwindSafe for EmulateArgs