pub struct InterceptAddArgs {
pub url_pattern: String,
pub capture: Option<String>,
pub respond: Option<String>,
pub status: u16,
}Fields
url_pattern: Stringcapture: Option<String>respond: Option<String>status: u16Trait Implementations
Sourceimpl Clone for InterceptAddArgs
impl Clone for InterceptAddArgs
Sourceimpl Debug for InterceptAddArgs
impl Debug for InterceptAddArgs
Sourceimpl Default for InterceptAddArgs
impl Default for InterceptAddArgs
Sourceimpl<'de> Deserialize<'de> for InterceptAddArgs
impl<'de> Deserialize<'de> for InterceptAddArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InterceptAddArgs
impl JsonSchema for InterceptAddArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InterceptAddArgs
impl RefUnwindSafe for InterceptAddArgs
impl Send for InterceptAddArgs
impl Sync for InterceptAddArgs
impl Unpin for InterceptAddArgs
impl UnsafeUnpin for InterceptAddArgs
impl UnwindSafe for InterceptAddArgs