pub struct LoadStateArgs {
pub path: String,
pub no_navigate: bool,
}Fields
path: StringTrait Implementations
Sourceimpl Clone for LoadStateArgs
impl Clone for LoadStateArgs
Sourceimpl Debug for LoadStateArgs
impl Debug for LoadStateArgs
Sourceimpl Default for LoadStateArgs
impl Default for LoadStateArgs
Sourceimpl<'de> Deserialize<'de> for LoadStateArgs
impl<'de> Deserialize<'de> for LoadStateArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoadStateArgs
impl JsonSchema for LoadStateArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoadStateArgs
impl RefUnwindSafe for LoadStateArgs
impl Send for LoadStateArgs
impl Sync for LoadStateArgs
impl Unpin for LoadStateArgs
impl UnsafeUnpin for LoadStateArgs
impl UnwindSafe for LoadStateArgs