pub struct MouseButtonArgs {
pub x: f64,
pub y: f64,
pub button: MouseButton,
}Fields
x: f64y: f64Trait Implementations
Sourceimpl Clone for MouseButtonArgs
impl Clone for MouseButtonArgs
Sourceimpl Debug for MouseButtonArgs
impl Debug for MouseButtonArgs
Sourceimpl<'de> Deserialize<'de> for MouseButtonArgs
impl<'de> Deserialize<'de> for MouseButtonArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MouseButtonArgs
impl JsonSchema for MouseButtonArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MouseButtonArgs
impl RefUnwindSafe for MouseButtonArgs
impl Send for MouseButtonArgs
impl Sync for MouseButtonArgs
impl Unpin for MouseButtonArgs
impl UnsafeUnpin for MouseButtonArgs
impl UnwindSafe for MouseButtonArgs