pub struct MouseMoveArgs {
pub x: f64,
pub y: f64,
}Fields
x: f64y: f64Trait Implementations
Sourceimpl Clone for MouseMoveArgs
impl Clone for MouseMoveArgs
Sourceimpl Debug for MouseMoveArgs
impl Debug for MouseMoveArgs
Sourceimpl<'de> Deserialize<'de> for MouseMoveArgs
impl<'de> Deserialize<'de> for MouseMoveArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MouseMoveArgs
impl JsonSchema for MouseMoveArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MouseMoveArgs
impl RefUnwindSafe for MouseMoveArgs
impl Send for MouseMoveArgs
impl Sync for MouseMoveArgs
impl Unpin for MouseMoveArgs
impl UnsafeUnpin for MouseMoveArgs
impl UnwindSafe for MouseMoveArgs