pub struct NetworkLogArgs {
pub limit: Option<usize>,
pub pattern: Option<String>,
pub method: Option<String>,
pub status: Option<u16>,
pub since: Option<u64>,
pub compact: bool,
}Fields
limit: Option<usize>pattern: Option<String>method: Option<String>status: Option<u16>since: Option<u64>compact: boolTrait Implementations
Sourceimpl Clone for NetworkLogArgs
impl Clone for NetworkLogArgs
Sourceimpl Debug for NetworkLogArgs
impl Debug for NetworkLogArgs
Sourceimpl Default for NetworkLogArgs
impl Default for NetworkLogArgs
Sourceimpl<'de> Deserialize<'de> for NetworkLogArgs
impl<'de> Deserialize<'de> for NetworkLogArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NetworkLogArgs
impl JsonSchema for NetworkLogArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NetworkLogArgs
impl RefUnwindSafe for NetworkLogArgs
impl Send for NetworkLogArgs
impl Sync for NetworkLogArgs
impl Unpin for NetworkLogArgs
impl UnsafeUnpin for NetworkLogArgs
impl UnwindSafe for NetworkLogArgs