pub struct NetworkWaitArgs {
pub pattern: Option<String>,
pub method: Option<String>,
pub status: Option<u16>,
pub timeout: Option<u64>,
pub since: Option<u64>,
pub include_existing: bool,
}Fields
pattern: Option<String>method: Option<String>status: Option<u16>timeout: Option<u64>since: Option<u64>include_existing: boolTrait Implementations
Sourceimpl Clone for NetworkWaitArgs
impl Clone for NetworkWaitArgs
Sourceimpl Debug for NetworkWaitArgs
impl Debug for NetworkWaitArgs
Sourceimpl Default for NetworkWaitArgs
impl Default for NetworkWaitArgs
Sourceimpl<'de> Deserialize<'de> for NetworkWaitArgs
impl<'de> Deserialize<'de> for NetworkWaitArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NetworkWaitArgs
impl JsonSchema for NetworkWaitArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NetworkWaitArgs
impl RefUnwindSafe for NetworkWaitArgs
impl Send for NetworkWaitArgs
impl Sync for NetworkWaitArgs
impl Unpin for NetworkWaitArgs
impl UnsafeUnpin for NetworkWaitArgs
impl UnwindSafe for NetworkWaitArgs