pub struct PageContext {
pub tab_id: String,
pub url: String,
pub title: String,
pub ready_state: String,
pub headings: Vec<String>,
pub messages: Vec<String>,
pub text_excerpt: String,
pub truncated: bool,
}Fields
tab_id: Stringurl: Stringtitle: Stringready_state: Stringheadings: Vec<String>messages: Vec<String>text_excerpt: Stringtruncated: boolTrait Implementations
Sourceimpl Clone for PageContext
impl Clone for PageContext
Sourceimpl Debug for PageContext
impl Debug for PageContext
Sourceimpl<'de> Deserialize<'de> for PageContext
impl<'de> Deserialize<'de> for PageContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PageContext
impl JsonSchema for PageContext
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PageContext
impl RefUnwindSafe for PageContext
impl Send for PageContext
impl Sync for PageContext
impl Unpin for PageContext
impl UnsafeUnpin for PageContext
impl UnwindSafe for PageContext