pub struct TextArgs {
pub text: String,
}Fields
text: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for TextArgs
impl<'de> Deserialize<'de> for TextArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TextArgs
impl JsonSchema for TextArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TextArgs
impl RefUnwindSafe for TextArgs
impl Send for TextArgs
impl Sync for TextArgs
impl Unpin for TextArgs
impl UnsafeUnpin for TextArgs
impl UnwindSafe for TextArgs