pub struct WaitArgs {
pub ms: Option<u64>,
pub text: Option<String>,
pub url: Option<String>,
pub load: Option<String>,
pub timeout: Option<u64>,
}Fields
ms: Option<u64>text: Option<String>url: Option<String>load: Option<String>timeout: Option<u64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for WaitArgs
impl<'de> Deserialize<'de> for WaitArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WaitArgs
impl JsonSchema for WaitArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WaitArgs
impl RefUnwindSafe for WaitArgs
impl Send for WaitArgs
impl Sync for WaitArgs
impl Unpin for WaitArgs
impl UnsafeUnpin for WaitArgs
impl UnwindSafe for WaitArgs